@@ -238,6 +238,9 @@ class Collection(Record):
         return CollectionQuery(self, self._get_a_collection_view(), **kwargs).execute()
 
     def get_rows(self, **kwargs):
+        if "limit" not in kwargs or kwargs["limit"] == -1:
+            kwargs["limit"] = self._get_total_rows()
+
         return self.query(**kwargs)
 
     def _convert_diff_to_changelist(self, difference, old_val, new_val):
@@ -256,6 +259,36 @@ class Collection(Record):
             remaining, old_val, new_val
         )
 
+    def _get_total_rows(self):
+        data = {
+            "collection": {
+                "id": self.id,
+                "spaceId": self._client.current_space.id,
+            },
+            "collectionView": {
+                "id": self._get_a_collection_view().id,
+                "spaceId": self._client.current_space.id,
+            },
+            "loader": {
+                "reducers": {
+                    "table:uncategorized:title:count": {
+                        "aggregation": {"aggregator": "count", "property": "title"},
+                        "type": "aggregation",
+                    }
+                },
+                "searchQuery": "",
+                "sort": [],
+                "userTimeZone": str(get_localzone()),
+                "type": "reducer",
+            },
+        }
+
+        response = self._client.post("queryCollection", data).json()
+
+        return response["result"]["reducerResults"]["table:uncategorized:title:count"][
+            "aggregationResult"
+        ]["value"]
+
 
 class CollectionView(Record):
     """
@@ -358,7 +391,6 @@ class CollectionQuery(object):
         type="table",
         aggregate=[],
         aggregations=[],
-        filter=[],
         sort=[],
         calendar_by="",
         group_by="",
@@ -373,7 +405,6 @@ class CollectionQuery(object):
         self.type = type
         self.aggregate = _normalize_query_data(aggregate, collection)
         self.aggregations = _normalize_query_data(aggregations, collection)
-        self.filter = _normalize_query_data(filter, collection)
         self.sort = _normalize_query_data(sort, collection)
         self.calendar_by = _normalize_property_name(calendar_by, collection)
         self.group_by = _normalize_property_name(group_by, collection)
@@ -391,7 +422,6 @@ class CollectionQuery(object):
             "type": self.type,
             "aggregate": self.aggregate,
             "aggregations": self.aggregations,
-            "filter": self.filter,
             "sort": self.sort,
             "calendar_by": self.calendar_by,
             "group_by": self.group_by,
@@ -400,8 +430,20 @@ class CollectionQuery(object):
 
         if self.limit == -1:
             # fetch remote total
+            kwargs["limit"] = 100000
+
             result = self._client.query_collection(**kwargs)
-            self.limit = result.get("total", -1)
+            g_result = result["reducerResults"]["collection_group_results"]
+
+            self.limit = len(g_result["blockIds"])
+
+            while g_result["hasMore"]:
+                kwargs["limit"] += 100000
+
+                result = self._client.query_collection(**kwargs)
+                g_result = result["reducerResults"]["collection_group_results"]
+
+                self.limit = len(g_result["blockIds"])
 
         kwargs["limit"] = self.limit
 
